---
title: <span class="badge object-type-scalar"></span> MegaFlopsPerSecond
---
# <span class="badge object-type-scalar"></span> MegaFlopsPerSecond

Computation: MFLOP/s

## Definition

```python
# Computation: MFLOP/s
MegaFlopsPerSecond: typing.Literal["mflops"] = "mflops"
```
